/* 
 * Copyright 2013 ScaleOut Software, Inc.
 * 
 * LICENSE AND DISCLAIMER
 * ----------------------
 * This material contains sample programming source code ("Sample Code").
 * ScaleOut Software, Inc. (SSI) grants you a nonexclusive license to compile, 
 * link, run, display, reproduce, and prepare derivative works of 
 * this Sample Code.  The Sample Code has not been thoroughly
 * tested under all conditions.  SSI, therefore, does not guarantee
 * or imply its reliability, serviceability, or function. SSI
 * provides no support services for the Sample Code.
 *
 * All Sample Code contained herein is provided to you "AS IS" without
 * any warranties of any kind. THE IMPLIED WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGMENT ARE EXPRESSLY
 * DISCLAIMED.  SOME JURISDICTIONS DO NOT ALLOW THE EXCLUSION OF IMPLIED
 * WARRANTIES, SO THE ABOVE EXCLUSIONS MAY NOT APPLY TO YOU.  IN NO 
 * EVENT WILL SSI BE LIABLE TO ANY PARTY FOR ANY DIRECT, INDIRECT, 
 * SPECIAL OR OTHER CONSEQUENTIAL DAMAGES FOR ANY USE OF THE SAMPLE CODE
 * INCLUDING, WITHOUT LIMITATION, ANY LOST PROFITS, BUSINESS 
 * INTERRUPTION, LOSS OF PROGRAMS OR OTHER DATA ON YOUR INFORMATION
 * HANDLING SYSTEM OR OTHERWISE, EVEN IF WE ARE EXPRESSLY ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGES.
 */

package com.scaleoutsoftware.demos.alertsdesk;

import java.awt.Color;
import java.awt.Component;
import javax.swing.JLabel;
import javax.swing.JTable;
import javax.swing.SwingConstants;
import javax.swing.table.TableCellRenderer;

/**
 * Highlights alerted positions in a JTable
 */
public class PositionTableRenderer extends JLabel
                                   implements TableCellRenderer
{
    public PositionTableRenderer()
    {
        setOpaque(true); // must do this for background to show up.
    }
    
    @Override
    public Component getTableCellRendererComponent(
                            JTable table, Object value,
                            boolean isSelected, boolean hasFocus,
                            int viewRowIndex, int viewColumnIndex) {

        setText(value.toString());
        
        // All columns in the data model except for the first two are numeric.
        // Make them right-justified. (We perform the view-to-model converversion
        // here because the user can drag columns to reorder them):
        if (table.convertColumnIndexToModel(viewColumnIndex) > 1)
            this.setHorizontalAlignment(SwingConstants.RIGHT);
        else
            this.setHorizontalAlignment(SwingConstants.LEFT);
        
        // Determine if the Position associated with this cell's row is alerted:
        PositionTableModel model = (PositionTableModel)table.getModel();
        
        if (isSelected) {
            // Always render normally if selected:
            setBackground(table.getSelectionBackground());
            setForeground(table.getSelectionForeground());
        } else {
            // Highlight if alerted. Note that sorting will dissociate the provided
            // row argument from the row index in the table's data model, thus the conversion:
            if (model.isRowAlerted(table.convertRowIndexToModel(viewRowIndex)))
                setBackground(Color.YELLOW);
            else
                setBackground(table.getBackground());
            
            setForeground(table.getForeground());
        }
        
        return this;
    }
    
}
