/* 
 * Copyright 2013 ScaleOut Software, Inc.
 * 
 * LICENSE AND DISCLAIMER
 * ----------------------
 * This material contains sample programming source code ("Sample Code").
 * ScaleOut Software, Inc. (SSI) grants you a nonexclusive license to compile, 
 * link, run, display, reproduce, and prepare derivative works of 
 * this Sample Code.  The Sample Code has not been thoroughly
 * tested under all conditions.  SSI, therefore, does not guarantee
 * or imply its reliability, serviceability, or function. SSI
 * provides no support services for the Sample Code.
 *
 * All Sample Code contained herein is provided to you "AS IS" without
 * any warranties of any kind. THE IMPLIED WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGMENT ARE EXPRESSLY
 * DISCLAIMED.  SOME JURISDICTIONS DO NOT ALLOW THE EXCLUSION OF IMPLIED
 * WARRANTIES, SO THE ABOVE EXCLUSIONS MAY NOT APPLY TO YOU.  IN NO 
 * EVENT WILL SSI BE LIABLE TO ANY PARTY FOR ANY DIRECT, INDIRECT, 
 * SPECIAL OR OTHER CONSEQUENTIAL DAMAGES FOR ANY USE OF THE SAMPLE CODE
 * INCLUDING, WITHOUT LIMITATION, ANY LOST PROFITS, BUSINESS 
 * INTERRUPTION, LOSS OF PROGRAMS OR OTHER DATA ON YOUR INFORMATION
 * HANDLING SYSTEM OR OTHERWISE, EVEN IF WE ARE EXPRESSLY ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGES.
 */

package com.scaleoutsoftware.demos.alertsdesk;

/**
 * A lightweight representation of a strategy that simply indicates whether
 * the strategy is alerted or not. Suitable for direct insertion into a JList
 * control.
 */
public class StrategyListItem implements Comparable<StrategyListItem> {
    private final int id;
    private volatile boolean alerted;

    public StrategyListItem(int id, boolean alerted) {
        this.id = id;
        this.alerted = alerted;
    }
    
    /**
     * @return user friendly name of the strategy. String returned here
     * is what's displayed when an instance of this type is inserted into
     * a JList.
     */
    @Override
    public String toString()
    {
        return "Strategy " + Integer.toString(id);
    }
    
    /**
     * @return the id of the strategy
     */
    public int getId() {
        return id;
    }
    
    /**
     * @return whether the strategy is alerted
     */
    public boolean isAlerted() {
        return alerted;
    }
    
    /**
     * @param alerted true to set the strategy list item to an alerted (highlighted) state
     */
    public void setAlerted(boolean alerted) {
        this.alerted = alerted;
    }

    

    /**
     * Comparison implementation for sorting
     * @param other  the Strategy to be compared
     * @return       a negative integer, zero, or a positive integer as this object 
     *               is less than, equal to, or greater than the specified object.
     */
    @Override
    public int compareTo(StrategyListItem other) {
        if (id > other.getId())
            return 1;
        else if (id < other.getId())
            return -1;
        else
            return 0;
    }

}
