/* 
 * Copyright 2013 ScaleOut Software, Inc.
 * 
 * LICENSE AND DISCLAIMER
 * ----------------------
 * This material contains sample programming source code ("Sample Code").
 * ScaleOut Software, Inc. (SSI) grants you a nonexclusive license to compile, 
 * link, run, display, reproduce, and prepare derivative works of 
 * this Sample Code.  The Sample Code has not been thoroughly
 * tested under all conditions.  SSI, therefore, does not guarantee
 * or imply its reliability, serviceability, or function. SSI
 * provides no support services for the Sample Code.
 *
 * All Sample Code contained herein is provided to you "AS IS" without
 * any warranties of any kind. THE IMPLIED WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGMENT ARE EXPRESSLY
 * DISCLAIMED.  SOME JURISDICTIONS DO NOT ALLOW THE EXCLUSION OF IMPLIED
 * WARRANTIES, SO THE ABOVE EXCLUSIONS MAY NOT APPLY TO YOU.  IN NO 
 * EVENT WILL SSI BE LIABLE TO ANY PARTY FOR ANY DIRECT, INDIRECT, 
 * SPECIAL OR OTHER CONSEQUENTIAL DAMAGES FOR ANY USE OF THE SAMPLE CODE
 * INCLUDING, WITHOUT LIMITATION, ANY LOST PROFITS, BUSINESS 
 * INTERRUPTION, LOSS OF PROGRAMS OR OTHER DATA ON YOUR INFORMATION
 * HANDLING SYSTEM OR OTHERWISE, EVEN IF WE ARE EXPRESSLY ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGES.
 */

package com.scaleoutsoftware.demos.common;

import java.io.Serializable;
import java.math.BigDecimal;

/**
 * Class used to store constants and common settings used by applications in this sample.
 * 
 * An instance of this class is stored in the ScaleOut StateServer in-memory data grid so that 
 * the market simulator application and the AlertSummary desktop application can easily communicate
 * settings with each other.
 */
public class Settings implements Serializable {
    private static final long serialVersionUID = 1L;
    public final static String STRATEGY_CACHE_NAME = "Strategy Cache";
    public final static String SETTINGS_CACHE_NAME = "Settings Cache";
    public final static String SUMMARY_CACHE_NAME = "Strategy Summary Cache";
    
    public final static String SETTINGS_OBJ_NAME = "Settings";
    public final static String SUMMARY_OBJ_NAME = "Alert Summary";
    public final static BigDecimal DEFAULT_MAX_DEVIATION_PCT = BigDecimal.ONE;

    private BigDecimal maxAllowedDeviationPercent = DEFAULT_MAX_DEVIATION_PCT;

    /**
     * Gets the maximum percentage that a position can vary from its targeted value before it enters
     * an alerted state.
     * 
     * This demonstration uses this setting during PMI operations to determine whether a position
     * (and the strategy holding it) should be flagged as alerted.
     * 
     * @return percentage
     */
    public BigDecimal getMaxAllowedDeviationPercent() {
        return maxAllowedDeviationPercent;
    }

    /**
     * Sets the maximum percentage that a position can vary from its targeted value before it enters
     * an alerted state.
     * 
     * This demonstration uses this setting during PMI operations to determine whether a position
     * (and the strategy holding it) should be flagged as alerted. The AlertSummary desktop application
     * can be used to adjust this value through the UI.
     * 
     * @param maxAllowedDeviationPercent new value
     */
    public void setMaxAllowedDeviationPercent(BigDecimal maxAllowedDeviationPercent) {
        this.maxAllowedDeviationPercent = maxAllowedDeviationPercent;
    }
}
