/* 
 * Copyright 2013 ScaleOut Software, Inc.
 * 
 * LICENSE AND DISCLAIMER
 * ----------------------
 * This material contains sample programming source code ("Sample Code").
 * ScaleOut Software, Inc. (SSI) grants you a nonexclusive license to compile, 
 * link, run, display, reproduce, and prepare derivative works of 
 * this Sample Code.  The Sample Code has not been thoroughly
 * tested under all conditions.  SSI, therefore, does not guarantee
 * or imply its reliability, serviceability, or function. SSI
 * provides no support services for the Sample Code.
 *
 * All Sample Code contained herein is provided to you "AS IS" without
 * any warranties of any kind. THE IMPLIED WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGMENT ARE EXPRESSLY
 * DISCLAIMED.  SOME JURISDICTIONS DO NOT ALLOW THE EXCLUSION OF IMPLIED
 * WARRANTIES, SO THE ABOVE EXCLUSIONS MAY NOT APPLY TO YOU.  IN NO 
 * EVENT WILL SSI BE LIABLE TO ANY PARTY FOR ANY DIRECT, INDIRECT, 
 * SPECIAL OR OTHER CONSEQUENTIAL DAMAGES FOR ANY USE OF THE SAMPLE CODE
 * INCLUDING, WITHOUT LIMITATION, ANY LOST PROFITS, BUSINESS 
 * INTERRUPTION, LOSS OF PROGRAMS OR OTHER DATA ON YOUR INFORMATION
 * HANDLING SYSTEM OR OTHERWISE, EVEN IF WE ARE EXPRESSLY ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGES.
 */

package com.scaleoutsoftware.demos.common;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.HashMap;

/**
 * Class containing PMI argument data needed to perform strategy updates via a NamedCache.invoke operation.
 * 
 * An object of this type is passed as an argument to the NamedCache.invoke distributed operation, 
 * giving all worker nodes an instant snapshot of the latest exchange prices when updating and 
 * evaluating strategies.
 */
public class StrategyUpdateArgs implements Serializable {
    private static final long serialVersionUID = 1L;
    private HashMap<String, Security> latestPrices;
    private BigDecimal maxAllowedDeviationPercent;
    
    /**
     * Constructor
     * @param latestPrices map of latest market prices for all securities in an exchange
     * @param maxAllowedDeviationPercent max % deviation that a position is allowed to have in a strategy
     */
    public StrategyUpdateArgs(HashMap<String, Security> latestPrices, BigDecimal maxAllowedDeviationPercent)
    {
        this.latestPrices = latestPrices;
        this.maxAllowedDeviationPercent = maxAllowedDeviationPercent;
    }

    /**
     * Gets a collection of latest market prices for all securities in an exchange
     * @return the latest prices
     */
    public HashMap<String, Security> getLatestPrices() {
        return latestPrices;
    }

    /**
     * Gets the max % deviation that a position is allowed to have in a strategy 
     * before an alert is tripped on that strategy.
     * @return the maxAllowedDeviationPercent
     */
    public BigDecimal getMaxAllowedDeviationPercent() {
        return maxAllowedDeviationPercent;
    }
}
